@@ -3,6 +3,7 @@ presentation_instances.py
 """
 
 population = [
+    # Diagrams
     {'Name': 'default', 'Drawing type': 'Starr class diagram'},
     {'Name': 'diagnostic', 'Drawing type': 'Starr class diagram'},
 
@@ -19,4 +20,8 @@ population = [
 
     {'Name': 'default', 'Drawing type': 'xUML domain diagram'},
     {'Name': 'default', 'Drawing type': 'xUML class collaboration diagram'},
+
+    # Frames
+    {'Name': 'default', 'Drawing type': 'OS Engineer large frame'},
+    {'Name': 'default', 'Drawing type': 'OS Engineer medium frame'},
 ]
\ No newline at end of file
