@@ -43,6 +43,19 @@ class LayoutVisitor(PTNodeVisitor):
         """Keyword argument"""
         return children[0]
 
+    def visit_padding(self, node, children):
+        """Keyword argument"""
+        d = dict(zip(['left', 'bottom', 'top', 'right'], children))
+        return d
+
+    def visit_frame(self, node, children):
+        """Keyword argument"""
+        return children[0]
+
+    def visit_frame_presentation(self, node, children):
+        """Keyword argument"""
+        return children[0]
+
     def visit_notation(self, node, children):
         """Keyword argument"""
         return children[0]
